@@ -25,9 +25,15 @@ from pkg_resources import iter_entry_points
 
 from opentelemetry import trace
 from opentelemetry.environment_variables import (
+    OTEL_LOGS_EXPORTER,
     OTEL_PYTHON_ID_GENERATOR,
     OTEL_TRACES_EXPORTER,
 )
+from opentelemetry.sdk._logs import (
+    LogEmitterProvider,
+    set_log_emitter_provider,
+)
+from opentelemetry.sdk._logs.export import BatchLogProcessor, LogExporter
 from opentelemetry.sdk.resources import Resource
 from opentelemetry.sdk.trace import TracerProvider
 from opentelemetry.sdk.trace.export import BatchSpanProcessor, SpanExporter
@@ -35,7 +41,7 @@ from opentelemetry.sdk.trace.id_generator import IdGenerator
 from opentelemetry.semconv.resource import ResourceAttributes
 
 _EXPORTER_OTLP = "otlp"
-_EXPORTER_OTLP_SPAN = "otlp_proto_grpc"
+_EXPORTER_OTLP_PROTO_GRPC = "otlp_proto_grpc"
 
 _RANDOM_ID_GENERATOR = "random"
 _DEFAULT_ID_GENERATOR = _RANDOM_ID_GENERATOR
@@ -45,22 +51,15 @@ def _get_id_generator() -> str:
     return environ.get(OTEL_PYTHON_ID_GENERATOR, _DEFAULT_ID_GENERATOR)
 
 
-def _get_exporter_names() -> Sequence[str]:
-    trace_exporters = environ.get(OTEL_TRACES_EXPORTER)
-
+def _get_exporter_names(names: str) -> Sequence[str]:
     exporters = set()
 
-    if trace_exporters and trace_exporters.lower().strip() != "none":
-        exporters.update(
-            {
-                trace_exporter.strip()
-                for trace_exporter in trace_exporters.split(",")
-            }
-        )
+    if names and names.lower().strip() != "none":
+        exporters.update({_exporter.strip() for _exporter in names.split(",")})
 
     if _EXPORTER_OTLP in exporters:
         exporters.remove(_EXPORTER_OTLP)
-        exporters.add(_EXPORTER_OTLP_SPAN)
+        exporters.add(_EXPORTER_OTLP_PROTO_GRPC)
 
     return list(exporters)
 
@@ -91,7 +90,29 @@ def _init_tracing(
         )
 
 
-def _import_tracer_provider_config_components(
+def _init_logging(
+    exporters: Dict[str, Sequence[LogExporter]],
+    auto_instrumentation_version: Optional[str] = None,
+):
+    # if env var OTEL_RESOURCE_ATTRIBUTES is given, it will read the service_name
+    # from the env variable else defaults to "unknown_service"
+    auto_resource = {}
+    # populate version if using auto-instrumentation
+    if auto_instrumentation_version:
+        auto_resource[
+            ResourceAttributes.TELEMETRY_AUTO_VERSION
+        ] = auto_instrumentation_version
+    provider = LogEmitterProvider(resource=Resource.create(auto_resource))
+    set_log_emitter_provider(provider)
+
+    for _, exporter_class in exporters.items():
+        exporter_args = {}
+        provider.add_log_processor(
+            BatchLogProcessor(exporter_class(**exporter_args))
+        )
+
+
+def _import_config_components(
     selected_components, entry_point_name
 ) -> Sequence[Tuple[str, object]]:
     component_entry_points = {
@@ -112,28 +133,34 @@ def _import_tracer_provider_config_components(
 
 
 def _import_exporters(
-    exporter_names: Sequence[str],
-) -> Dict[str, Type[SpanExporter]]:
+    trace_exporter_names: Sequence[str],
+    log_exporter_names: Sequence[str],
+) -> Tuple[Dict[str, Type[SpanExporter]], Dict[str, Type[LogExporter]]]:
     trace_exporters = {}
+    log_exporters = {}
 
-    for (
-        exporter_name,
-        exporter_impl,
-    ) in _import_tracer_provider_config_components(
-        exporter_names, "opentelemetry_traces_exporter"
+    for (exporter_name, exporter_impl,) in _import_config_components(
+        trace_exporter_names, "opentelemetry_traces_exporter"
     ):
         if issubclass(exporter_impl, SpanExporter):
             trace_exporters[exporter_name] = exporter_impl
         else:
             raise RuntimeError(f"{exporter_name} is not a trace exporter")
-    return trace_exporters
+
+    for (exporter_name, exporter_impl,) in _import_config_components(
+        log_exporter_names, "opentelemetry_logs_exporter"
+    ):
+        if issubclass(exporter_impl, LogExporter):
+            log_exporters[exporter_name] = exporter_impl
+        else:
+            raise RuntimeError(f"{exporter_name} is not a log exporter")
+
+    return trace_exporters, log_exporters
 
 
 def _import_id_generator(id_generator_name: str) -> IdGenerator:
     # pylint: disable=unbalanced-tuple-unpacking
-    [
-        (id_generator_name, id_generator_impl)
-    ] = _import_tracer_provider_config_components(
+    [(id_generator_name, id_generator_impl)] = _import_config_components(
         [id_generator_name.strip()], "opentelemetry_id_generator"
     )
 
@@ -144,11 +171,14 @@ def _import_id_generator(id_generator_name: str) -> IdGenerator:
 
 
 def _initialize_components(auto_instrumentation_version):
-    exporter_names = _get_exporter_names()
-    trace_exporters = _import_exporters(exporter_names)
+    trace_exporters, log_exporters = _import_exporters(
+        _get_exporter_names(environ.get(OTEL_TRACES_EXPORTER)),
+        _get_exporter_names(environ.get(OTEL_LOGS_EXPORTER)),
+    )
     id_generator_name = _get_id_generator()
     id_generator = _import_id_generator(id_generator_name)
     _init_tracing(trace_exporters, id_generator, auto_instrumentation_version)
+    _init_logging(log_exporters, auto_instrumentation_version)
 
 
 class _BaseConfigurator(ABC):
