@@ -18,19 +18,20 @@ from unittest import TestCase
 from unittest.mock import patch
 
 from opentelemetry import trace
-from opentelemetry.environment_variables import (
-    OTEL_PYTHON_ID_GENERATOR,
-    OTEL_TRACES_EXPORTER,
-)
+from opentelemetry.environment_variables import OTEL_PYTHON_ID_GENERATOR
 from opentelemetry.sdk._configuration import (
     _EXPORTER_OTLP,
-    _EXPORTER_OTLP_SPAN,
+    _EXPORTER_OTLP_PROTO_GRPC,
     _get_exporter_names,
     _get_id_generator,
+    _import_exporters,
     _import_id_generator,
     _init_tracing,
 )
+from opentelemetry.sdk._logs.export import ConsoleLogExporter
+from opentelemetry.sdk._metrics.export import ConsoleMetricExporter
 from opentelemetry.sdk.resources import SERVICE_NAME, Resource
+from opentelemetry.sdk.trace.export import ConsoleSpanExporter
 from opentelemetry.sdk.trace.id_generator import IdGenerator, RandomIdGenerator
 
 
@@ -164,22 +165,38 @@ class TestTraceInit(TestCase):
 
 class TestExporterNames(TestCase):
     def test_otlp_exporter_overwrite(self):
-        for exporter in [_EXPORTER_OTLP, _EXPORTER_OTLP_SPAN]:
-            with patch.dict(environ, {OTEL_TRACES_EXPORTER: exporter}):
-                self.assertEqual(_get_exporter_names(), [_EXPORTER_OTLP_SPAN])
+        for exporter in [_EXPORTER_OTLP, _EXPORTER_OTLP_PROTO_GRPC]:
+            self.assertEqual(
+                _get_exporter_names(exporter), [_EXPORTER_OTLP_PROTO_GRPC]
+            )
 
-    @patch.dict(environ, {OTEL_TRACES_EXPORTER: "jaeger,zipkin"})
     def test_multiple_exporters(self):
-        self.assertEqual(sorted(_get_exporter_names()), ["jaeger", "zipkin"])
+        self.assertEqual(
+            sorted(_get_exporter_names("jaeger,zipkin")), ["jaeger", "zipkin"]
+        )
 
-    @patch.dict(environ, {OTEL_TRACES_EXPORTER: "none"})
     def test_none_exporters(self):
-        self.assertEqual(sorted(_get_exporter_names()), [])
+        self.assertEqual(sorted(_get_exporter_names("none")), [])
 
-    @patch.dict(environ, {}, clear=True)
     def test_no_exporters(self):
-        self.assertEqual(sorted(_get_exporter_names()), [])
+        self.assertEqual(sorted(_get_exporter_names(None)), [])
 
-    @patch.dict(environ, {OTEL_TRACES_EXPORTER: ""})
     def test_empty_exporters(self):
-        self.assertEqual(sorted(_get_exporter_names()), [])
+        self.assertEqual(sorted(_get_exporter_names("")), [])
+
+
+class TestImportExporters(TestCase):
+    def test_console_exporters(self):
+        trace_exporters, logs_exporters = _import_exporters(
+            ["console"], ["console"]
+        )
+        self.assertEqual(
+            trace_exporters["console"].__class__, ConsoleSpanExporter.__class__
+        )
+        self.assertEqual(
+            logs_exporters["console"].__class__, ConsoleLogExporter.__class__
+        )
+        self.assertEqual(
+            logs_exporters["console"].__class__,
+            ConsoleMetricExporter.__class__,
+        )
